@@ -6,7 +6,11 @@ class Case(SimpleNamespace):
     Minimal container for a reusable test case.
     """
 
-    def __init__(self, **kwargs):
+    def __init__(self, case: "Case" = None, **kwargs):
+        if case is not None:
+            super().__init__(**case.__dict__.copy())
+            return
+
         if "name" not in kwargs:
             raise ValueError(f"Case name is required")
 
@@ -26,7 +30,7 @@ class Case(SimpleNamespace):
         Copies the test case.
         """
 
-        return SimpleNamespace(**self.__dict__.copy())
+        return Case(**self.__dict__.copy())
 
     def copy_update(self, **kwargs):
         """
@@ -36,4 +40,4 @@ class Case(SimpleNamespace):
 
         cpy = self.__dict__.copy()
         cpy.update(kwargs)
-        return SimpleNamespace(**cpy)
+        return Case(**cpy)
